@@ -53,7 +53,7 @@
 #include <tqlayout.h>
 #include <tqptrlist.h>
 #include <tqpainter.h>
-#include <koFrame.h>
+#include <KoFrame.h>
 
 class KMPlayerFactory : public KParts::Factory {
 public:
@@ -94,7 +94,7 @@ KParts::Part *KMPlayerFactory::createPartObject
 KOfficeMPlayer::KOfficeMPlayer (TQWidget *parentWidget, const char *widgetName, TQObject* parent, const char* name, bool singleViewMode) 
   : KoDocument (parentWidget, widgetName, parent, name, singleViewMode),
     m_config (new TDEConfig ("kmplayerrc")),
-    m_player (new KMPlayer (parentWidget, 0L, 0L, 0L, m_config))
+    m_player (new KMPlayer::PartBase (parentWidget, 0L, 0L, 0L, m_config))
 {
     setInstance (KMPlayerFactory::instance (), false);
     setReadWrite (false);
@@ -111,7 +111,7 @@ void KOfficeMPlayer::paintContent (TQPainter& p, const TQRect& r, bool, double,
     p.fillRect (r, TQBrush (TQColor (0, 0, 0)));
 }
 
-bool KOfficeMPlayer::initDoc() {
+bool KOfficeMPlayer::initDoc(InitDocFlags flags, TQWidget* parentWidget) {
     kdDebug() << "KOfficeMPlayer::initDoc" << endl;
     return true;
 }
@@ -133,6 +133,11 @@ bool KOfficeMPlayer::loadOasis (const TQDomDocument &, KoOasisStyles &, const TQ
     return true;
 }
 
+bool KOfficeMPlayer::saveOasis( KoStore* store, KoXmlWriter* manifestWriter )
+{
+    return true;
+}
+
 TQDomDocument KOfficeMPlayer::saveXML() {
     TQDomDocument doc = createDomDocument ("kmplayer", TQString::number(1.0));
     TQDomElement docelm = doc.documentElement();
