@@ -44,7 +44,7 @@ class TVChannel;
  * Base class for sources having a sub menu in the application
  */
 class KMPLAYER_NO_EXPORT KMPlayerMenuSource : public KMPlayer::Source {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KMPlayerMenuSource (const TQString & n, KMPlayerApp * app, TQPopupMenu * m, const char * src);
@@ -59,7 +59,7 @@ protected:
  * Preference page for DVD
  */
 class KMPLAYER_NO_EXPORT KMPlayerPrefSourcePageDVD : public TQFrame {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KMPlayerPrefSourcePageDVD (TQWidget * parent);
@@ -73,7 +73,7 @@ public:
  * Source from DVD
  */
 class KMPLAYER_NO_EXPORT KMPlayerDVDSource : public KMPlayerMenuSource, public KMPlayer::PreferencesPage {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KMPlayerDVDSource (KMPlayerApp * app, TQPopupMenu * m);
@@ -113,7 +113,7 @@ private:
  * Source from DVDNav
  */
 class KMPLAYER_NO_EXPORT KMPlayerDVDNavSource : public KMPlayerMenuSource {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KMPlayerDVDNavSource (KMPlayerApp * app, TQPopupMenu * m);
@@ -133,7 +133,7 @@ public slots:
  * Preference page for VCD
  */
 class KMPLAYER_NO_EXPORT KMPlayerPrefSourcePageVCD : public TQFrame {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KMPlayerPrefSourcePageVCD (TQWidget * parent);
@@ -147,7 +147,7 @@ public:
  * Source from VCD
  */
 class KMPLAYER_NO_EXPORT KMPlayerVCDSource : public KMPlayerMenuSource, public KMPlayer::PreferencesPage {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KMPlayerVCDSource (KMPlayerApp * app, TQPopupMenu * m);
@@ -174,7 +174,7 @@ private:
  * Source from AudoCD
  */
 class KMPLAYER_NO_EXPORT KMPlayerAudioCDSource : public KMPlayerMenuSource {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KMPlayerAudioCDSource (KMPlayerApp * app, TQPopupMenu * m);
@@ -194,7 +194,7 @@ private:
  * Source from stdin (for the backends, not kmplayer)
  */
 class KMPLAYER_NO_EXPORT KMPlayerPipeSource : public KMPlayer::Source {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KMPlayerPipeSource (KMPlayerApp * app);
