@@ -275,7 +275,7 @@ KMPlayerMenuButton::KMPlayerMenuButton (TQWidget * parent, TQBoxLayout * l, cons
    l->addWidget (this);
 }
 
-KDE_NO_EXPORT void KMPlayerMenuButton::enterEvent (TQEvent *) {
+TDE_NO_EXPORT void KMPlayerMenuButton::enterEvent (TQEvent *) {
     emit mouseEntered ();
 }
 
@@ -284,7 +284,7 @@ KDE_NO_EXPORT void KMPlayerMenuButton::enterEvent (TQEvent *) {
 KDE_NO_CDTOR_EXPORT KMPlayerPopupMenu::KMPlayerPopupMenu (TQWidget * parent)
  : TDEPopupMenu (parent, "kde_kmplayer_popupmenu") {}
 
-KDE_NO_EXPORT void KMPlayerPopupMenu::leaveEvent (TQEvent *) {
+TDE_NO_EXPORT void KMPlayerPopupMenu::leaveEvent (TQEvent *) {
     emit mouseLeft ();
 }
 
@@ -440,7 +440,7 @@ KDE_NO_CDTOR_EXPORT ControlPanel::ControlPanel(TQWidget * parent, View * view)
     connect (m_audioMenu, TQ_SIGNAL (mouseLeft ()), this, TQ_SLOT (menuMouseLeft ()));
 }
 
-KDE_NO_EXPORT void ControlPanel::setPalette (const TQPalette & pal) {
+TDE_NO_EXPORT void ControlPanel::setPalette (const TQPalette & pal) {
     TQWidget::setPalette (pal);
     TQColor c = paletteForegroundColor ();
     strncpy (xpm_fg_color, TQString(TQString().sprintf(".      c #%02x%02x%02x", c.red(), c.green(),c.blue())).ascii(), 31);
@@ -461,7 +461,7 @@ KDE_NO_EXPORT void ControlPanel::setPalette (const TQPalette & pal) {
     m_buttons[button_blue]->setIconSet (TQIconSet (TQPixmap (blue_xpm)));
 }
 
-KDE_NO_EXPORT void ControlPanel::timerEvent (TQTimerEvent * e) {
+TDE_NO_EXPORT void ControlPanel::timerEvent (TQTimerEvent * e) {
     if (e->timerId () == m_popup_timer) {
         m_popup_timer = 0;
         if (m_button_monitored == button_config) {
@@ -519,12 +519,12 @@ void ControlPanel::setAutoControls (bool b) {
     m_view->updateLayout ();
 }
 
-KDE_NO_EXPORT void ControlPanel::showPopupMenu () {
+TDE_NO_EXPORT void ControlPanel::showPopupMenu () {
     m_view->updateVolume ();
     m_popupMenu->exec (m_buttons [button_config]->mapToGlobal (TQPoint (0, maximumSize ().height ())));
 }
 
-KDE_NO_EXPORT void ControlPanel::showLanguageMenu () {
+TDE_NO_EXPORT void ControlPanel::showLanguageMenu () {
     m_languageMenu->exec (m_buttons [button_language]->mapToGlobal (TQPoint (0, maximumSize ().height ())));
 }
 
@@ -536,7 +536,7 @@ void ControlPanel::showPositionSlider (bool show) {
         m_view->updateLayout ();
 }
 
-KDE_NO_EXPORT void ControlPanel::setupPositionSlider (bool show) {
+TDE_NO_EXPORT void ControlPanel::setupPositionSlider (bool show) {
     int h = show ? button_height_with_slider : button_height_only_buttons;
     m_posSlider->setEnabled (false);
     m_posSlider->setValue (0);
@@ -558,7 +558,7 @@ KDE_NO_EXPORT void ControlPanel::setupPositionSlider (bool show) {
     setMaximumSize (2500, h + (show ? 8 : 2 ));
 }
 
-KDE_NO_EXPORT int ControlPanel::preferedHeight () {
+TDE_NO_EXPORT int ControlPanel::preferedHeight () {
     return m_posSlider->isVisible () ?
         button_height_with_slider + 8 : button_height_only_buttons + 2;
 }
@@ -593,12 +593,12 @@ void ControlPanel::setPlaying (bool play) {
     }
 }
 
-KDE_NO_EXPORT void ControlPanel::setRecording (bool record) {
+TDE_NO_EXPORT void ControlPanel::setRecording (bool record) {
     if (record != m_buttons[button_record]->isOn ())
         m_buttons[button_record]->toggle ();
 }
 
-KDE_NO_EXPORT void ControlPanel::setPlayingProgress (int pos, int len) {
+TDE_NO_EXPORT void ControlPanel::setPlayingProgress (int pos, int len) {
     m_posSlider->setEnabled (false);
     m_progress_length = len;
     showPositionSlider (len > 0);
@@ -616,7 +616,7 @@ KDE_NO_EXPORT void ControlPanel::setPlayingProgress (int pos, int len) {
     m_posSlider->setEnabled (true);
 }
 
-KDE_NO_EXPORT void ControlPanel::setLoadingProgress (int pos) {
+TDE_NO_EXPORT void ControlPanel::setLoadingProgress (int pos) {
     if (pos > 0 && pos < 100 && !m_posSlider->isVisible ())
         showPositionSlider (true);
     m_posSlider->setEnabled (false);
@@ -627,7 +627,7 @@ KDE_NO_EXPORT void ControlPanel::setLoadingProgress (int pos) {
     m_posSlider->setValue (pos);
 }
 
-KDE_NO_EXPORT void ControlPanel::buttonClicked () {
+TDE_NO_EXPORT void ControlPanel::buttonClicked () {
     if (m_popup_timer) {
         killTimer (m_popup_timer);
         m_popup_timer = 0;
@@ -639,7 +639,7 @@ KDE_NO_EXPORT void ControlPanel::buttonClicked () {
         showPopupMenu ();
 }
 
-KDE_NO_EXPORT void ControlPanel::buttonMouseEntered () {
+TDE_NO_EXPORT void ControlPanel::buttonMouseEntered () {
     if (!m_popup_timer) {
         if (sender () == m_buttons [button_config]) {
             if (!m_popupMenu->isVisible ()) {
@@ -655,12 +655,12 @@ KDE_NO_EXPORT void ControlPanel::buttonMouseEntered () {
     }
 }
 
-KDE_NO_EXPORT void ControlPanel::menuMouseLeft () {
+TDE_NO_EXPORT void ControlPanel::menuMouseLeft () {
     if (!m_popdown_timer && !m_popup_clicked)
         m_popdown_timer = startTimer (400);
 }
 
-KDE_NO_EXPORT void ControlPanel::setLanguages (const TQStringList & alang, const TQStringList & slang) {
+TDE_NO_EXPORT void ControlPanel::setLanguages (const TQStringList & alang, const TQStringList & slang) {
     int sz = (int) alang.size ();
     bool showbutton = (sz > 0);
     m_audioMenu->clear ();
@@ -677,7 +677,7 @@ KDE_NO_EXPORT void ControlPanel::setLanguages (const TQStringList & alang, const
         m_buttons [button_language]->hide ();
 }
 
-KDE_NO_EXPORT void ControlPanel::selectSubtitle (int id) {
+TDE_NO_EXPORT void ControlPanel::selectSubtitle (int id) {
     if (m_subtitleMenu->isItemChecked (id))
         return;
     int size = m_subtitleMenu->count ();
@@ -689,7 +689,7 @@ KDE_NO_EXPORT void ControlPanel::selectSubtitle (int id) {
     m_subtitleMenu->setItemChecked (id, true);
 }
 
-KDE_NO_EXPORT void ControlPanel::selectAudioLanguage (int id) {
+TDE_NO_EXPORT void ControlPanel::selectAudioLanguage (int id) {
     kdDebug () << "ControlPanel::selectAudioLanguage " << id << endl;
     if (m_audioMenu->isItemChecked (id))
         return;
