@@ -48,8 +48,8 @@
 #include <tdeio/job.h>
 
 #ifdef HAVE_DBUS
+# include "dbus/dbus.h"
 # include <kstaticdeleter.h>
-# include <dbus/connection.h>
 #endif
 
 #include "kmplayerview.h"
@@ -1897,19 +1897,16 @@ TDE_NO_EXPORT void FFMpeg::processStopped (TDEProcess *) {
 struct KMPLAYER_NO_EXPORT DBusStatic {
     DBusStatic ();
     ~DBusStatic ();
-    DBusQt::Connection *connection; // FIXME find a way to detect if already connected
     DBusConnection *dbus_connnection;
 };
 
 static DBusStatic * dbus_static = 0L;
 
 DBusStatic::DBusStatic ()
- : connection (new DBusQt::Connection (DBUS_BUS_SESSION, 0L)),
-   dbus_connnection (0L) {}
+ : dbus_connnection (0L) {}
 
 DBusStatic::~DBusStatic () {
     dbus_connection_unref (dbus_connnection);
-    delete connection;
     dbus_static = 0L;
 }
 
@@ -2228,7 +2225,7 @@ TDE_NO_EXPORT bool NpPlayer::deMediafiedPlay () {
                 dbus_message_iter_close_container (&ait, &dit);
             }
             dbus_message_iter_close_container (&it, &ait);
-            dbus_message_set_no_reply (msg, TRUE);
+            dbus_message_set_no_reply (msg, true);
             dbus_connection_send (dbus_static->dbus_connnection, msg, NULL);
             dbus_message_unref (msg);
             dbus_connection_flush (dbus_static->dbus_connnection);
@@ -2353,7 +2350,7 @@ void NpPlayer::sendFinish (TQ_UINT32 sid, TQ_UINT32 bytes, NpStream::Reason beca
                 DBUS_TYPE_UINT32, &bytes,
                 DBUS_TYPE_UINT32, &reason,
                 DBUS_TYPE_INVALID);
-        dbus_message_set_no_reply (msg, TRUE);
+        dbus_message_set_no_reply (msg, true);
         dbus_connection_send (dbus_static->dbus_connnection, msg, NULL);
         dbus_message_unref (msg);
         dbus_connection_flush (dbus_static->dbus_connnection);
@@ -2378,7 +2375,7 @@ TDE_NO_EXPORT bool NpPlayer::stop () {
                 "/plugin",
                 "org.kde.kmplayer.backend",
                 "quit");
-        dbus_message_set_no_reply (msg, TRUE);
+        dbus_message_set_no_reply (msg, true);
         dbus_connection_send (dbus_static->dbus_connnection, msg, NULL);
         dbus_message_unref (msg);
         dbus_connection_flush (dbus_static->dbus_connnection);
@@ -2428,7 +2425,7 @@ TDE_NO_EXPORT void NpPlayer::streamRedirected (TQ_UINT32 sid, const KURL &u) {
                 "org.kde.kmplayer.backend",
                 "redirected");
         dbus_message_append_args(msg, DBUS_TYPE_STRING, &cu, DBUS_TYPE_INVALID);
-        dbus_message_set_no_reply (msg, TRUE);
+        dbus_message_set_no_reply (msg, true);
         dbus_connection_send (dbus_static->dbus_connnection, msg, NULL);
         dbus_message_unref (msg);
         dbus_connection_flush (dbus_static->dbus_connnection);
@@ -2498,7 +2495,7 @@ TDE_NO_EXPORT void NpPlayer::processStreams () {
                     DBUS_TYPE_STRING, &mt,
                     DBUS_TYPE_UINT32, &stream->content_length,
                     DBUS_TYPE_INVALID);
-            dbus_message_set_no_reply (msg, TRUE);
+            dbus_message_set_no_reply (msg, true);
             dbus_connection_send (dbus_static->dbus_connnection, msg, NULL);
             dbus_message_unref (msg);
             dbus_connection_flush (dbus_static->dbus_connnection);
