@@ -31,12 +31,14 @@ http://dbus.freedesktop.org/doc/dbus/libdbus-tutorial.html
 #include <fcntl.h>
 
 #include <glib.h>
+#include <glib/gprintf.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 
 #define DBUS_API_SUBJECT_TO_CHANGE
 #include <dbus/dbus.h>
 #include <dbus/dbus-glib.h>
+#include <dbus/dbus-glib-lowlevel.h>
 
 #define XP_UNIX
 #define MOZ_X11
@@ -119,6 +121,10 @@ static void print (const char * format, ...) {
 
 /*----------------%<---------------------------------------------------------*/
 
+static gint identifierCompare (gconstpointer a, gconstpointer b) {
+    return strcmp((const char*)a, (const char*)b);
+}
+
 static gint streamCompare (gconstpointer a, gconstpointer b) {
     return (long)a - (long)b;
 }
@@ -1527,7 +1533,7 @@ int main (int argc, char **argv) {
         return 1;
     }
 
-    identifiers = g_tree_new (strcmp);
+    identifiers = g_tree_new (identifierCompare);
     stream_list = g_tree_new (streamCompare);
 
     g_timeout_add (0, initPlayer, NULL);
