@@ -135,7 +135,7 @@ KDE_NO_CDTOR_EXPORT Preferences::Preferences(PartBase * player, Settings * setti
     connect (this, TQ_SIGNAL (defaultClicked ()), TQ_SLOT (confirmDefaults ()));
 }
 
-KDE_NO_EXPORT void Preferences::setPage (const char * name) {
+TDE_NO_EXPORT void Preferences::setPage (const char * name) {
     TQObject * o = child (name, "TQFrame");
     if (!o) return;
     TQFrame * page = static_cast <TQFrame *>(o);
@@ -150,7 +150,7 @@ KDE_NO_EXPORT void Preferences::setPage (const char * name) {
     showPage (pageIndex (t->parentWidget ()));
 }
 
-KDE_NO_EXPORT void Preferences::addPrefPage (PreferencesPage * page) {
+TDE_NO_EXPORT void Preferences::addPrefPage (PreferencesPage * page) {
     TQString item, subitem, icon;
     TQFrame * frame;
     TQTabWidget * tab;
@@ -171,7 +171,7 @@ KDE_NO_EXPORT void Preferences::addPrefPage (PreferencesPage * page) {
     tab->insertTab (frame, subitem);
 }
 
-KDE_NO_EXPORT void Preferences::removePrefPage(PreferencesPage * page) {
+TDE_NO_EXPORT void Preferences::removePrefPage(PreferencesPage * page) {
     TQString item, subitem, icon;
     page->prefLocation (item, icon, subitem);
     if (item.isEmpty ())
@@ -301,22 +301,22 @@ KDE_NO_CDTOR_EXPORT PrefGeneralPageLooks::PrefGeneralPageLooks (TQWidget *parent
     layout->addItem (new TQSpacerItem (0, 0, TQSizePolicy::Minimum, TQSizePolicy::Expanding));
 }
 
-KDE_NO_EXPORT void PrefGeneralPageLooks::colorItemChanged (int c) {
+TDE_NO_EXPORT void PrefGeneralPageLooks::colorItemChanged (int c) {
     if (c < int (ColorSetting::last_target))
         colorbutton->setColor (colors[c].newcolor);
 }
 
-KDE_NO_EXPORT void PrefGeneralPageLooks::colorCanged (const TQColor & c) {
+TDE_NO_EXPORT void PrefGeneralPageLooks::colorCanged (const TQColor & c) {
     if (colorscombo->currentItem () < int (ColorSetting::last_target))
         colors[colorscombo->currentItem ()].newcolor = c;
 }
 
-KDE_NO_EXPORT void PrefGeneralPageLooks::fontItemChanged (int f) {
+TDE_NO_EXPORT void PrefGeneralPageLooks::fontItemChanged (int f) {
     if (f < int (FontSetting::last_target))
         fontbutton->setFont (fonts[f].newfont);
 }
 
-KDE_NO_EXPORT void PrefGeneralPageLooks::fontClicked () {
+TDE_NO_EXPORT void PrefGeneralPageLooks::fontClicked () {
     if (fontscombo->currentItem () < int (FontSetting::last_target)) {
         TQFont myfont = fonts [fontscombo->currentItem ()].newfont;
         int res = TDEFontDialog::getFont (myfont, false, this);
@@ -387,10 +387,10 @@ KDE_NO_CDTOR_EXPORT PrefSourcePageURL::PrefSourcePageURL (TQWidget *parent)
              this, TQ_SLOT (slotTextChanged (const TQString &)));
 }
 
-KDE_NO_EXPORT void PrefSourcePageURL::slotBrowse () {
+TDE_NO_EXPORT void PrefSourcePageURL::slotBrowse () {
 }
 
-KDE_NO_EXPORT void PrefSourcePageURL::slotTextChanged (const TQString &) {
+TDE_NO_EXPORT void PrefSourcePageURL::slotTextChanged (const TQString &) {
     changed = true;
 }
 
@@ -439,19 +439,19 @@ KDE_NO_CDTOR_EXPORT PrefRecordPage::PrefRecordPage (TQWidget *parent, PartBase *
     connect (replay, TQ_SIGNAL (clicked (int)), this, TQ_SLOT (replayClicked (int)));
 }
 
-KDE_NO_EXPORT void PrefRecordPage::recordingStarted () {
+TDE_NO_EXPORT void PrefRecordPage::recordingStarted () {
     recordButton->setText (i18n ("Stop Recording"));
     url->setEnabled (false);
     topLevelWidget ()->hide ();
 }
 
-KDE_NO_EXPORT void PrefRecordPage::recordingFinished () {
+TDE_NO_EXPORT void PrefRecordPage::recordingFinished () {
     recordButton->setText (i18n ("Start Recording"));
     url->setEnabled (true);
     TQTimer::singleShot (0, m_player, TQ_SLOT(recordingStopped())); // removed from PartBase::setSource because PartBase::recordingStopped calls openURL and that will call PartBase::setSource and TQt doesn't like disconnecting/connecting a signal that is current
 }
 
-KDE_NO_EXPORT void PrefRecordPage::sourceChanged (Source * olds, Source * nws) {
+TDE_NO_EXPORT void PrefRecordPage::sourceChanged (Source * olds, Source * nws) {
     int id = 0;
     int nr_recs = 0;
     if (olds) {
@@ -472,7 +472,7 @@ KDE_NO_EXPORT void PrefRecordPage::sourceChanged (Source * olds, Source * nws) {
     recordButton->setEnabled (nr_recs > 0);
 }
 
-KDE_NO_EXPORT void PrefRecordPage::recorderClicked (int id) {
+TDE_NO_EXPORT void PrefRecordPage::recorderClicked (int id) {
     bool b = false;
     TQButton *recBtn = recorder->find(id);
     if (recBtn)
@@ -485,11 +485,11 @@ KDE_NO_EXPORT void PrefRecordPage::recorderClicked (int id) {
 
 }
 
-KDE_NO_EXPORT void PrefRecordPage::replayClicked (int id) {
+TDE_NO_EXPORT void PrefRecordPage::replayClicked (int id) {
     replaytime->setEnabled (id == Settings::ReplayAfter);
 }
 
-KDE_NO_EXPORT void PrefRecordPage::slotRecord () {
+TDE_NO_EXPORT void PrefRecordPage::slotRecord () {
     connect (m_player->source (), TQ_SIGNAL (stopPlaying ()),
              this, TQ_SLOT (playingStopped ()));
     if (m_player->process () && m_player->process ()->playing ())
@@ -498,7 +498,7 @@ KDE_NO_EXPORT void PrefRecordPage::slotRecord () {
         playingStopped ();
 }
 
-KDE_NO_EXPORT void PrefRecordPage::playingStopped () {
+TDE_NO_EXPORT void PrefRecordPage::playingStopped () {
     disconnect (m_player->source (), TQ_SIGNAL (stopPlaying ()),
                 this, TQ_SLOT (playingStopped ()));
     if (!url->lineEdit()->text().isEmpty()) {
@@ -524,7 +524,7 @@ KDE_NO_EXPORT void PrefRecordPage::playingStopped () {
 KDE_NO_CDTOR_EXPORT RecorderPage::RecorderPage (TQWidget *parent, PartBase * player)
  : TQFrame (parent), next (0L), m_player (player) {}
 
-KDE_NO_EXPORT void RecorderPage::record () {
+TDE_NO_EXPORT void RecorderPage::record () {
     Process * proc = m_player->recorders () [recorderName ()];
     m_player->setRecorder (recorderName ());
     Recorder * rec = dynamic_cast <Recorder *> (proc);
@@ -556,11 +556,11 @@ KDE_NO_CDTOR_EXPORT PrefMEncoderPage::PrefMEncoderPage (TQWidget *parent, PartBa
     connect (format, TQ_SIGNAL (clicked (int)), this, TQ_SLOT (formatClicked (int)));
 }
 
-KDE_NO_EXPORT void PrefMEncoderPage::formatClicked (int id) {
+TDE_NO_EXPORT void PrefMEncoderPage::formatClicked (int id) {
     arguments->setEnabled (!!id);
 }
 
-KDE_NO_EXPORT void PrefMEncoderPage::record () {
+TDE_NO_EXPORT void PrefMEncoderPage::record () {
 #if KDE_IS_VERSION(3,1,90)
     m_player->settings ()->recordcopy = !format->selectedId ();
 #else
@@ -570,7 +570,7 @@ KDE_NO_EXPORT void PrefMEncoderPage::record () {
     RecorderPage::record ();
 }
 
-KDE_NO_EXPORT TQString PrefMEncoderPage::name () {
+TDE_NO_EXPORT TQString PrefMEncoderPage::name () {
     return i18n ("&MEncoder");
 }
 
@@ -578,7 +578,7 @@ KDE_NO_CDTOR_EXPORT PrefMPlayerDumpstreamPage::PrefMPlayerDumpstreamPage (TQWidg
     hide();
 }
 
-KDE_NO_EXPORT TQString PrefMPlayerDumpstreamPage::name () {
+TDE_NO_EXPORT TQString PrefMPlayerDumpstreamPage::name () {
     return i18n ("MPlayer -&dumpstream");
 }
 
@@ -593,12 +593,12 @@ KDE_NO_CDTOR_EXPORT PrefFFMpegPage::PrefFFMpegPage (TQWidget *parent, PartBase *
     layout->addItem (new TQSpacerItem (0, 0, TQSizePolicy::Minimum, TQSizePolicy::Expanding));
 }
 
-KDE_NO_EXPORT void PrefFFMpegPage::record () {
+TDE_NO_EXPORT void PrefFFMpegPage::record () {
     m_player->settings ()->ffmpegarguments = arguments->text ();
     RecorderPage::record ();
 }
 
-KDE_NO_EXPORT TQString PrefFFMpegPage::name () {
+TDE_NO_EXPORT TQString PrefFFMpegPage::name () {
     return i18n ("&FFMpeg");
 }
 
@@ -607,7 +607,7 @@ KDE_NO_CDTOR_EXPORT PrefXinePage::PrefXinePage (TQWidget *parent, PartBase * pla
     hide();
 }
 
-KDE_NO_EXPORT TQString PrefXinePage::name () {
+TDE_NO_EXPORT TQString PrefXinePage::name () {
     return i18n ("&Xine");
 }
 #endif
@@ -834,7 +834,7 @@ KDE_NO_CDTOR_EXPORT PrefOPPagePostProc::PrefOPPagePostProc(TQWidget *parent) : T
     PostprocessingOptions->adjustSize();
 }
 
-KDE_NO_EXPORT void Preferences::confirmDefaults() {
+TDE_NO_EXPORT void Preferences::confirmDefaults() {
 	// TODO: Switch to KMessageBox
 	switch( TQMessageBox::warning( this, i18n("Reset Settings?"),
         i18n("You are about to have all your settings overwritten with defaults.\nPlease confirm.\n"),
@@ -846,7 +846,7 @@ KDE_NO_EXPORT void Preferences::confirmDefaults() {
 
 }
 
-KDE_NO_EXPORT void Preferences::setDefaults() {
+TDE_NO_EXPORT void Preferences::setDefaults() {
 	m_GeneralPageGeneral->keepSizeRatio->setChecked(true);
 	m_GeneralPageGeneral->loop->setChecked(false);
 	m_GeneralPageGeneral->seekTime->setValue(10);
